--
-- BetterFuelUsageFix
-- Specialization to deactivate the 'BetterFuelUsage' Mod from TyKonKet for the Pony
--
-- @author  	Ifko[nator]
-- @date  		15.01.2018
-- @version		1.0


BetterFuelUsageFix = {};

local modFilename, _, _ = Utils.removeModDirectory(g_currentModDirectory);

function BetterFuelUsageFix:loadMap(name)
	self.modName = "";
	self.modNamePrint = string.sub(modFilename, 0, (string.len(modFilename) - 1));
	
	for _, mod in pairs(ModsUtil.modList) do
		if SpecializationUtil.getSpecialization(tostring(mod.modName) .. ".betterFuelUsage") ~= nil then		
			print("[Info from the BetterFuelUsageFix.lua]: Found the BetterFuelUsage.lua in the '" .. mod.modName ..".zip'.");
			
			if g_modIsLoaded[tostring(mod.modName)] then	
				self.modName = _G[tostring(mod.modName)];
			end;
		end;
	end;
	
	if self.modName ~= "" then
		self.modName.BetterFuelUsage.update = Utils.overwrittenFunction(self.modName.BetterFuelUsage.update, BetterFuelUsageFix.updateFix);
		self.modName.BetterFuelUsage.updateTick = Utils.overwrittenFunction(self.modName.BetterFuelUsage.updateTick, BetterFuelUsageFix.updateTickFix);
		self.modName.BetterFuelUsage.draw = Utils.overwrittenFunction(self.modName.BetterFuelUsage.draw, BetterFuelUsageFix.drawFix);
		self.modName.BetterFuelUsage.drawRightMeter = Utils.overwrittenFunction(self.modName.BetterFuelUsage.drawRightMeter, BetterFuelUsageFix.drawRightMeterFix);
		self.modName.BetterFuelUsage.drawLeftMeter = Utils.overwrittenFunction(self.modName.BetterFuelUsage.drawLeftMeter, BetterFuelUsageFix.drawLeftMeterFix);
		self.modName.BetterFuelUsage.readStream = Utils.overwrittenFunction(self.modName.BetterFuelUsage.readStream, BetterFuelUsageFix.readStreamFix);
		self.modName.BetterFuelUsage.writeStream = Utils.overwrittenFunction(self.modName.BetterFuelUsage.writeStream, BetterFuelUsageFix.writeStreamFix);
		self.modName.BetterFuelUsage.readUpdateStream = Utils.overwrittenFunction(self.modName.BetterFuelUsage.readUpdateStream, BetterFuelUsageFix.readUpdateStreamFix);
		self.modName.BetterFuelUsage.writeUpdateStream = Utils.overwrittenFunction(self.modName.BetterFuelUsage.writeUpdateStream, BetterFuelUsageFix.writeUpdateStreamFix);
		
		print("[Info from the BetterFuelUsageFix.lua]: Overwrite some functions from the BetterFuelUsage.lua to stop this for the '" .. self.modNamePrint ..".zip'.");
	else
		print("[Info from the BetterFuelUsageFix.lua]: NOT overwrite some functions from the BetterFuelUsage.lua to stop this for the '" .. self.modNamePrint ..".zip', because the better fuel usage mod was not loaded!");
	end;
end;

function BetterFuelUsageFix:updateFix(superFunc, dt)
	if self.pony == nil then
		superFunc(self, dt);
	end;
end;

function BetterFuelUsageFix:updateTickFix(superFunc, dt)
	if self.pony == nil then
		superFunc(self, dt);
	end;
end;

function BetterFuelUsageFix:drawFix(superFunc)
	if self.pony == nil then
		superFunc(self);
	end;
end;

function BetterFuelUsageFix:drawRightMeterFix(superFunc, value)
	if self.pony == nil then
		superFunc(self, value);
	end;
end;

function BetterFuelUsageFix:drawLeftMeterFix(superFunc, value)
	if self.pony == nil then
		superFunc(self, value);
	end;
end;

function BetterFuelUsageFix:readStreamFix(superFunc, streamId, connection)
	if self.pony == nil then
		superFunc(self, streamId, connection);
	end;
end;

function BetterFuelUsageFix:writeStreamFix(superFunc, streamId, connection)
	if self.pony == nil then
		superFunc(self, streamId, connection);
	end;
end; 

function BetterFuelUsageFix:readUpdateStreamFix(superFunc, streamId, connection)
	if self.pony == nil then
		superFunc(self, streamId, connection);
	end;
end;

function BetterFuelUsageFix:writeUpdateStreamFix(superFunc, streamId, connection)
	if self.pony == nil then
		superFunc(self, streamId, connection);
	end;
end; 

--## Unused but needed functions

function BetterFuelUsageFix:update(dt)end;
function BetterFuelUsageFix:deleteMap()end;
function BetterFuelUsageFix:keyEvent(unicode, sym, modifier, isDown)end;
function BetterFuelUsageFix:mouseEvent(posX, posY, isDown, isUp, button)end;
function BetterFuelUsageFix:draw()end;

addModEventListener(BetterFuelUsageFix);